
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/struct.proto', package='tensorflow', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n%tensorflow/core/protobuf/struct.proto\x12\ntensorflow\x1a&tensorflow/core/framework/tensor.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"\x90\x05\n\x0fStructuredValue\x12+\n\nnone_value\x18\x01 \x01(\x0b2\x15.tensorflow.NoneValueH\x00\x12\x17\n\rfloat64_value\x18\x0b \x01(\x01H\x00\x12\x15\n\x0bint64_value\x18\x0c \x01(\x12H\x00\x12\x16\n\x0cstring_value\x18\r \x01(\tH\x00\x12\x14\n\nbool_value\x18\x0e \x01(\x08H\x00\x12:\n\x12tensor_shape_value\x18\x1f \x01(\x0b2\x1c.tensorflow.TensorShapeProtoH\x00\x122\n\x12tensor_dtype_value\x18  \x01(\x0e2\x14.tensorflow.DataTypeH\x00\x128\n\x11tensor_spec_value\x18! \x01(\x0b2\x1b.tensorflow.TensorSpecProtoH\x00\x124\n\x0ftype_spec_value\x18" \x01(\x0b2\x19.tensorflow.TypeSpecProtoH\x00\x12G\n\x19bounded_tensor_spec_value\x18# \x01(\x0b2".tensorflow.BoundedTensorSpecProtoH\x00\x12+\n\nlist_value\x183 \x01(\x0b2\x15.tensorflow.ListValueH\x00\x12-\n\x0btuple_value\x184 \x01(\x0b2\x16.tensorflow.TupleValueH\x00\x12+\n\ndict_value\x185 \x01(\x0b2\x15.tensorflow.DictValueH\x00\x128\n\x11named_tuple_value\x186 \x01(\x0b2\x1b.tensorflow.NamedTupleValueH\x00B\x06\n\x04kind"\x0b\n\tNoneValue"8\n\tListValue\x12+\n\x06values\x18\x01 \x03(\x0b2\x1b.tensorflow.StructuredValue"9\n\nTupleValue\x12+\n\x06values\x18\x01 \x03(\x0b2\x1b.tensorflow.StructuredValue"\x8a\x01\n\tDictValue\x121\n\x06fields\x18\x01 \x03(\x0b2!.tensorflow.DictValue.FieldsEntry\x1aJ\n\x0bFieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b2\x1b.tensorflow.StructuredValue:\x028\x01"D\n\tPairValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b2\x1b.tensorflow.StructuredValue"F\n\x0fNamedTupleValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x06values\x18\x02 \x03(\x0b2\x15.tensorflow.PairValue"q\n\x0fTensorSpecProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12#\n\x05dtype\x18\x03 \x01(\x0e2\x14.tensorflow.DataType"\xcc\x01\n\x16BoundedTensorSpecProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12#\n\x05dtype\x18\x03 \x01(\x0e2\x14.tensorflow.DataType\x12(\n\x07minimum\x18\x04 \x01(\x0b2\x17.tensorflow.TensorProto\x12(\n\x07maximum\x18\x05 \x01(\x0b2\x17.tensorflow.TensorProto"\xdb\x03\n\rTypeSpecProto\x12@\n\x0ftype_spec_class\x18\x01 \x01(\x0e2\'.tensorflow.TypeSpecProto.TypeSpecClass\x12/\n\ntype_state\x18\x02 \x01(\x0b2\x1b.tensorflow.StructuredValue\x12\x1c\n\x14type_spec_class_name\x18\x03 \x01(\t"\xb8\x02\n\rTypeSpecClass\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x16\n\x12SPARSE_TENSOR_SPEC\x10\x01\x12\x17\n\x13INDEXED_SLICES_SPEC\x10\x02\x12\x16\n\x12RAGGED_TENSOR_SPEC\x10\x03\x12\x15\n\x11TENSOR_ARRAY_SPEC\x10\x04\x12\x15\n\x11DATA_DATASET_SPEC\x10\x05\x12\x16\n\x12DATA_ITERATOR_SPEC\x10\x06\x12\x11\n\rOPTIONAL_SPEC\x10\x07\x12\x14\n\x10PER_REPLICA_SPEC\x10\x08\x12\x11\n\rVARIABLE_SPEC\x10\t\x12\x16\n\x12ROW_PARTITION_SPEC\x10\n\x12\x18\n\x14REGISTERED_TYPE_SPEC\x10\x0c\x12\x17\n\x13EXTENSION_TYPE_SPEC\x10\r"\x04\x08\x0b\x10\x0bBWZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_TYPESPECPROTO_TYPESPECCLASS = _descriptor.EnumDescriptor(name='TypeSpecClass', full_name='tensorflow.TypeSpecProto.TypeSpecClass', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNKNOWN', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='SPARSE_TENSOR_SPEC', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='INDEXED_SLICES_SPEC', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='RAGGED_TENSOR_SPEC', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TENSOR_ARRAY_SPEC', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DATA_DATASET_SPEC', index=5, number=5, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DATA_ITERATOR_SPEC', index=6, number=6, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='OPTIONAL_SPEC', index=7, number=7, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='PER_REPLICA_SPEC', index=8, number=8, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='VARIABLE_SPEC', index=9, number=9, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='ROW_PARTITION_SPEC', index=10, number=10, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='REGISTERED_TYPE_SPEC', index=11, number=12, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='EXTENSION_TYPE_SPEC', index=12, number=13, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1736, serialized_end=2048)
_sym_db.RegisterEnumDescriptor(_TYPESPECPROTO_TYPESPECCLASS)
_STRUCTUREDVALUE = _descriptor.Descriptor(name='StructuredValue', full_name='tensorflow.StructuredValue', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='none_value', full_name='tensorflow.StructuredValue.none_value', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='float64_value', full_name='tensorflow.StructuredValue.float64_value', index=1, number=11, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='int64_value', full_name='tensorflow.StructuredValue.int64_value', index=2, number=12, type=18, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='string_value', full_name='tensorflow.StructuredValue.string_value', index=3, number=13, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bool_value', full_name='tensorflow.StructuredValue.bool_value', index=4, number=14, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_shape_value', full_name='tensorflow.StructuredValue.tensor_shape_value', index=5, number=31, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_dtype_value', full_name='tensorflow.StructuredValue.tensor_dtype_value', index=6, number=32, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_spec_value', full_name='tensorflow.StructuredValue.tensor_spec_value', index=7, number=33, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type_spec_value', full_name='tensorflow.StructuredValue.type_spec_value', index=8, number=34, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bounded_tensor_spec_value', full_name='tensorflow.StructuredValue.bounded_tensor_spec_value', index=9, number=35, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='list_value', full_name='tensorflow.StructuredValue.list_value', index=10, number=51, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tuple_value', full_name='tensorflow.StructuredValue.tuple_value', index=11, number=52, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dict_value', full_name='tensorflow.StructuredValue.dict_value', index=12, number=53, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='named_tuple_value', full_name='tensorflow.StructuredValue.named_tuple_value', index=13, number=54, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='kind', full_name='tensorflow.StructuredValue.kind', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=179, serialized_end=835)
_NONEVALUE = _descriptor.Descriptor(name='NoneValue', full_name='tensorflow.NoneValue', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=837, serialized_end=848)
_LISTVALUE = _descriptor.Descriptor(name='ListValue', full_name='tensorflow.ListValue', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='values', full_name='tensorflow.ListValue.values', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=850, serialized_end=906)
_TUPLEVALUE = _descriptor.Descriptor(name='TupleValue', full_name='tensorflow.TupleValue', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='values', full_name='tensorflow.TupleValue.values', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=908, serialized_end=965)
_DICTVALUE_FIELDSENTRY = _descriptor.Descriptor(name='FieldsEntry', full_name='tensorflow.DictValue.FieldsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.DictValue.FieldsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.DictValue.FieldsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1032, serialized_end=1106)
_DICTVALUE = _descriptor.Descriptor(name='DictValue', full_name='tensorflow.DictValue', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='fields', full_name='tensorflow.DictValue.fields', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_DICTVALUE_FIELDSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=968, serialized_end=1106)
_PAIRVALUE = _descriptor.Descriptor(name='PairValue', full_name='tensorflow.PairValue', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.PairValue.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.PairValue.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1108, serialized_end=1176)
_NAMEDTUPLEVALUE = _descriptor.Descriptor(name='NamedTupleValue', full_name='tensorflow.NamedTupleValue', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.NamedTupleValue.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='values', full_name='tensorflow.NamedTupleValue.values', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1178, serialized_end=1248)
_TENSORSPECPROTO = _descriptor.Descriptor(name='TensorSpecProto', full_name='tensorflow.TensorSpecProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.TensorSpecProto.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.TensorSpecProto.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.TensorSpecProto.dtype', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1250, serialized_end=1363)
_BOUNDEDTENSORSPECPROTO = _descriptor.Descriptor(name='BoundedTensorSpecProto', full_name='tensorflow.BoundedTensorSpecProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.BoundedTensorSpecProto.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.BoundedTensorSpecProto.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.BoundedTensorSpecProto.dtype', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='minimum', full_name='tensorflow.BoundedTensorSpecProto.minimum', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='maximum', full_name='tensorflow.BoundedTensorSpecProto.maximum', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1366, serialized_end=1570)
_TYPESPECPROTO = _descriptor.Descriptor(name='TypeSpecProto', full_name='tensorflow.TypeSpecProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='type_spec_class', full_name='tensorflow.TypeSpecProto.type_spec_class', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type_state', full_name='tensorflow.TypeSpecProto.type_state', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type_spec_class_name', full_name='tensorflow.TypeSpecProto.type_spec_class_name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_TYPESPECPROTO_TYPESPECCLASS], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1573, serialized_end=2048)
_STRUCTUREDVALUE.fields_by_name['none_value'].message_type = _NONEVALUE
_STRUCTUREDVALUE.fields_by_name['tensor_shape_value'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_STRUCTUREDVALUE.fields_by_name['tensor_dtype_value'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_STRUCTUREDVALUE.fields_by_name['tensor_spec_value'].message_type = _TENSORSPECPROTO
_STRUCTUREDVALUE.fields_by_name['type_spec_value'].message_type = _TYPESPECPROTO
_STRUCTUREDVALUE.fields_by_name['bounded_tensor_spec_value'].message_type = _BOUNDEDTENSORSPECPROTO
_STRUCTUREDVALUE.fields_by_name['list_value'].message_type = _LISTVALUE
_STRUCTUREDVALUE.fields_by_name['tuple_value'].message_type = _TUPLEVALUE
_STRUCTUREDVALUE.fields_by_name['dict_value'].message_type = _DICTVALUE
_STRUCTUREDVALUE.fields_by_name['named_tuple_value'].message_type = _NAMEDTUPLEVALUE
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['none_value'])
_STRUCTUREDVALUE.fields_by_name['none_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['float64_value'])
_STRUCTUREDVALUE.fields_by_name['float64_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['int64_value'])
_STRUCTUREDVALUE.fields_by_name['int64_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['string_value'])
_STRUCTUREDVALUE.fields_by_name['string_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['bool_value'])
_STRUCTUREDVALUE.fields_by_name['bool_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['tensor_shape_value'])
_STRUCTUREDVALUE.fields_by_name['tensor_shape_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['tensor_dtype_value'])
_STRUCTUREDVALUE.fields_by_name['tensor_dtype_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['tensor_spec_value'])
_STRUCTUREDVALUE.fields_by_name['tensor_spec_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['type_spec_value'])
_STRUCTUREDVALUE.fields_by_name['type_spec_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['bounded_tensor_spec_value'])
_STRUCTUREDVALUE.fields_by_name['bounded_tensor_spec_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['list_value'])
_STRUCTUREDVALUE.fields_by_name['list_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['tuple_value'])
_STRUCTUREDVALUE.fields_by_name['tuple_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['dict_value'])
_STRUCTUREDVALUE.fields_by_name['dict_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_STRUCTUREDVALUE.oneofs_by_name['kind'].fields.append(_STRUCTUREDVALUE.fields_by_name['named_tuple_value'])
_STRUCTUREDVALUE.fields_by_name['named_tuple_value'].containing_oneof = _STRUCTUREDVALUE.oneofs_by_name['kind']
_LISTVALUE.fields_by_name['values'].message_type = _STRUCTUREDVALUE
_TUPLEVALUE.fields_by_name['values'].message_type = _STRUCTUREDVALUE
_DICTVALUE_FIELDSENTRY.fields_by_name['value'].message_type = _STRUCTUREDVALUE
_DICTVALUE_FIELDSENTRY.containing_type = _DICTVALUE
_DICTVALUE.fields_by_name['fields'].message_type = _DICTVALUE_FIELDSENTRY
_PAIRVALUE.fields_by_name['value'].message_type = _STRUCTUREDVALUE
_NAMEDTUPLEVALUE.fields_by_name['values'].message_type = _PAIRVALUE
_TENSORSPECPROTO.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_TENSORSPECPROTO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_BOUNDEDTENSORSPECPROTO.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_BOUNDEDTENSORSPECPROTO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_BOUNDEDTENSORSPECPROTO.fields_by_name['minimum'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_BOUNDEDTENSORSPECPROTO.fields_by_name['maximum'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_TYPESPECPROTO.fields_by_name['type_spec_class'].enum_type = _TYPESPECPROTO_TYPESPECCLASS
_TYPESPECPROTO.fields_by_name['type_state'].message_type = _STRUCTUREDVALUE
_TYPESPECPROTO_TYPESPECCLASS.containing_type = _TYPESPECPROTO
DESCRIPTOR.message_types_by_name['StructuredValue'] = _STRUCTUREDVALUE
DESCRIPTOR.message_types_by_name['NoneValue'] = _NONEVALUE
DESCRIPTOR.message_types_by_name['ListValue'] = _LISTVALUE
DESCRIPTOR.message_types_by_name['TupleValue'] = _TUPLEVALUE
DESCRIPTOR.message_types_by_name['DictValue'] = _DICTVALUE
DESCRIPTOR.message_types_by_name['PairValue'] = _PAIRVALUE
DESCRIPTOR.message_types_by_name['NamedTupleValue'] = _NAMEDTUPLEVALUE
DESCRIPTOR.message_types_by_name['TensorSpecProto'] = _TENSORSPECPROTO
DESCRIPTOR.message_types_by_name['BoundedTensorSpecProto'] = _BOUNDEDTENSORSPECPROTO
DESCRIPTOR.message_types_by_name['TypeSpecProto'] = _TYPESPECPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
StructuredValue = _reflection.GeneratedProtocolMessageType('StructuredValue', (_message.Message,), {'DESCRIPTOR': _STRUCTUREDVALUE, '__module__': 'tensorflow.core.protobuf.struct_pb2'})
_sym_db.RegisterMessage(StructuredValue)
NoneValue = _reflection.GeneratedProtocolMessageType('NoneValue', (_message.Message,), {'DESCRIPTOR': _NONEVALUE, '__module__': 'tensorflow.core.protobuf.struct_pb2'})
_sym_db.RegisterMessage(NoneValue)
ListValue = _reflection.GeneratedProtocolMessageType('ListValue', (_message.Message,), {'DESCRIPTOR': _LISTVALUE, '__module__': 'tensorflow.core.protobuf.struct_pb2'})
_sym_db.RegisterMessage(ListValue)
TupleValue = _reflection.GeneratedProtocolMessageType('TupleValue', (_message.Message,), {'DESCRIPTOR': _TUPLEVALUE, '__module__': 'tensorflow.core.protobuf.struct_pb2'})
_sym_db.RegisterMessage(TupleValue)
DictValue = _reflection.GeneratedProtocolMessageType('DictValue', (_message.Message,), {'FieldsEntry': _reflection.GeneratedProtocolMessageType('FieldsEntry', (_message.Message,), {'DESCRIPTOR': _DICTVALUE_FIELDSENTRY, '__module__': 'tensorflow.core.protobuf.struct_pb2'}), 'DESCRIPTOR': _DICTVALUE, '__module__': 'tensorflow.core.protobuf.struct_pb2'})
_sym_db.RegisterMessage(DictValue)
_sym_db.RegisterMessage(DictValue.FieldsEntry)
PairValue = _reflection.GeneratedProtocolMessageType('PairValue', (_message.Message,), {'DESCRIPTOR': _PAIRVALUE, '__module__': 'tensorflow.core.protobuf.struct_pb2'})
_sym_db.RegisterMessage(PairValue)
NamedTupleValue = _reflection.GeneratedProtocolMessageType('NamedTupleValue', (_message.Message,), {'DESCRIPTOR': _NAMEDTUPLEVALUE, '__module__': 'tensorflow.core.protobuf.struct_pb2'})
_sym_db.RegisterMessage(NamedTupleValue)
TensorSpecProto = _reflection.GeneratedProtocolMessageType('TensorSpecProto', (_message.Message,), {'DESCRIPTOR': _TENSORSPECPROTO, '__module__': 'tensorflow.core.protobuf.struct_pb2'})
_sym_db.RegisterMessage(TensorSpecProto)
BoundedTensorSpecProto = _reflection.GeneratedProtocolMessageType('BoundedTensorSpecProto', (_message.Message,), {'DESCRIPTOR': _BOUNDEDTENSORSPECPROTO, '__module__': 'tensorflow.core.protobuf.struct_pb2'})
_sym_db.RegisterMessage(BoundedTensorSpecProto)
TypeSpecProto = _reflection.GeneratedProtocolMessageType('TypeSpecProto', (_message.Message,), {'DESCRIPTOR': _TYPESPECPROTO, '__module__': 'tensorflow.core.protobuf.struct_pb2'})
_sym_db.RegisterMessage(TypeSpecProto)
DESCRIPTOR._options = None
_DICTVALUE_FIELDSENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/allocation_description.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x1bAllocationDescriptionProtosP\x01Z]github.com/tensorflow/tensorflow/tensorflow/go/core/framework/allocation_description_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n6tensorflow/core/framework/allocation_description.proto\x12\ntensorflow"\xa3\x01\n\x15AllocationDescription\x12\x17\n\x0frequested_bytes\x18\x01 \x01(\x03\x12\x17\n\x0fallocated_bytes\x18\x02 \x01(\x03\x12\x16\n\x0eallocator_name\x18\x03 \x01(\t\x12\x15\n\rallocation_id\x18\x04 \x01(\x03\x12\x1c\n\x14has_single_reference\x18\x05 \x01(\x08\x12\x0b\n\x03ptr\x18\x06 \x01(\x04B\x9b\x01\n\x18org.tensorflow.frameworkB\x1bAllocationDescriptionProtosP\x01Z]github.com/tensorflow/tensorflow/tensorflow/go/core/framework/allocation_description_go_proto\xf8\x01\x01b\x06proto3')
_ALLOCATIONDESCRIPTION = _descriptor.Descriptor(name='AllocationDescription', full_name='tensorflow.AllocationDescription', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='requested_bytes', full_name='tensorflow.AllocationDescription.requested_bytes', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocated_bytes', full_name='tensorflow.AllocationDescription.allocated_bytes', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocator_name', full_name='tensorflow.AllocationDescription.allocator_name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocation_id', full_name='tensorflow.AllocationDescription.allocation_id', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='has_single_reference', full_name='tensorflow.AllocationDescription.has_single_reference', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='ptr', full_name='tensorflow.AllocationDescription.ptr', index=5, number=6, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=71, serialized_end=234)
DESCRIPTOR.message_types_by_name['AllocationDescription'] = _ALLOCATIONDESCRIPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
AllocationDescription = _reflection.GeneratedProtocolMessageType('AllocationDescription', (_message.Message,), {'DESCRIPTOR': _ALLOCATIONDESCRIPTION, '__module__': 'tensorflow.core.framework.allocation_description_pb2'})
_sym_db.RegisterMessage(AllocationDescription)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.protobuf import meta_graph_pb2 as tensorflow_dot_core_dot_protobuf_dot_meta__graph__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/saved_model.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x10SavedModelProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n*tensorflow/core/protobuf/saved_model.proto\x12\ntensorflow\x1a)tensorflow/core/protobuf/meta_graph.proto"_\n\nSavedModel\x12"\n\x1asaved_model_schema_version\x18\x01 \x01(\x03\x12-\n\x0bmeta_graphs\x18\x02 \x03(\x0b2\x18.tensorflow.MetaGraphDefB\x88\x01\n\x18org.tensorflow.frameworkB\x10SavedModelProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_protobuf_dot_meta__graph__pb2.DESCRIPTOR])
_SAVEDMODEL = _descriptor.Descriptor(name='SavedModel', full_name='tensorflow.SavedModel', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='saved_model_schema_version', full_name='tensorflow.SavedModel.saved_model_schema_version', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='meta_graphs', full_name='tensorflow.SavedModel.meta_graphs', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=101, serialized_end=196)
_SAVEDMODEL.fields_by_name['meta_graphs'].message_type = tensorflow_dot_core_dot_protobuf_dot_meta__graph__pb2._METAGRAPHDEF
DESCRIPTOR.message_types_by_name['SavedModel'] = _SAVEDMODEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
SavedModel = _reflection.GeneratedProtocolMessageType('SavedModel', (_message.Message,), {'DESCRIPTOR': _SAVEDMODEL, '__module__': 'tensorflow.core.protobuf.saved_model_pb2'})
_sym_db.RegisterMessage(SavedModel)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/trace_events.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x11TraceEventsProtosP\x01ZHgithub.com/tensorflow/tensorflow/tensorflow/go/core/core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n4tensorflow/core/profiler/protobuf/trace_events.proto\x12\x13tensorflow.profiler"\xc5\x01\n\x05Trace\x128\n\x07devices\x18\x01 \x03(\x0b2\'.tensorflow.profiler.Trace.DevicesEntry\x125\n\x0ctrace_events\x18\x04 \x03(\x0b2\x1f.tensorflow.profiler.TraceEvent\x1aK\n\x0cDevicesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12*\n\x05value\x18\x02 \x01(\x0b2\x1b.tensorflow.profiler.Device:\x028\x01"\xb9\x01\n\x06Device\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12=\n\tresources\x18\x03 \x03(\x0b2*.tensorflow.profiler.Device.ResourcesEntry\x1aO\n\x0eResourcesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12,\n\x05value\x18\x02 \x01(\x0b2\x1d.tensorflow.profiler.Resource:\x028\x01"A\n\x08Resource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\r\x12\x12\n\nsort_index\x18\x03 \x01(\r"\xd3\x01\n\nTraceEvent\x12\x11\n\tdevice_id\x18\x01 \x01(\r\x12\x13\n\x0bresource_id\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0ctimestamp_ps\x18\t \x01(\x04\x12\x13\n\x0bduration_ps\x18\n \x01(\x04\x127\n\x04args\x18\x0b \x03(\x0b2).tensorflow.profiler.TraceEvent.ArgsEntry\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01B|\n\x18org.tensorflow.frameworkB\x11TraceEventsProtosP\x01ZHgithub.com/tensorflow/tensorflow/tensorflow/go/core/core_protos_go_proto\xf8\x01\x01b\x06proto3')
_TRACE_DEVICESENTRY = _descriptor.Descriptor(name='DevicesEntry', full_name='tensorflow.profiler.Trace.DevicesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.Trace.DevicesEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.Trace.DevicesEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=200, serialized_end=275)
_TRACE = _descriptor.Descriptor(name='Trace', full_name='tensorflow.profiler.Trace', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='devices', full_name='tensorflow.profiler.Trace.devices', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='trace_events', full_name='tensorflow.profiler.Trace.trace_events', index=1, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TRACE_DEVICESENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=78, serialized_end=275)
_DEVICE_RESOURCESENTRY = _descriptor.Descriptor(name='ResourcesEntry', full_name='tensorflow.profiler.Device.ResourcesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.Device.ResourcesEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.Device.ResourcesEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=384, serialized_end=463)
_DEVICE = _descriptor.Descriptor(name='Device', full_name='tensorflow.profiler.Device', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.Device.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_id', full_name='tensorflow.profiler.Device.device_id', index=1, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='resources', full_name='tensorflow.profiler.Device.resources', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_DEVICE_RESOURCESENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=278, serialized_end=463)
_RESOURCE = _descriptor.Descriptor(name='Resource', full_name='tensorflow.profiler.Resource', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.Resource.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='resource_id', full_name='tensorflow.profiler.Resource.resource_id', index=1, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='sort_index', full_name='tensorflow.profiler.Resource.sort_index', index=2, number=3, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=465, serialized_end=530)
_TRACEEVENT_ARGSENTRY = _descriptor.Descriptor(name='ArgsEntry', full_name='tensorflow.profiler.TraceEvent.ArgsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.TraceEvent.ArgsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.TraceEvent.ArgsEntry.value', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=701, serialized_end=744)
_TRACEEVENT = _descriptor.Descriptor(name='TraceEvent', full_name='tensorflow.profiler.TraceEvent', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device_id', full_name='tensorflow.profiler.TraceEvent.device_id', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='resource_id', full_name='tensorflow.profiler.TraceEvent.resource_id', index=1, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.TraceEvent.name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='timestamp_ps', full_name='tensorflow.profiler.TraceEvent.timestamp_ps', index=3, number=9, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='duration_ps', full_name='tensorflow.profiler.TraceEvent.duration_ps', index=4, number=10, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='args', full_name='tensorflow.profiler.TraceEvent.args', index=5, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TRACEEVENT_ARGSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=533, serialized_end=744)
_TRACE_DEVICESENTRY.fields_by_name['value'].message_type = _DEVICE
_TRACE_DEVICESENTRY.containing_type = _TRACE
_TRACE.fields_by_name['devices'].message_type = _TRACE_DEVICESENTRY
_TRACE.fields_by_name['trace_events'].message_type = _TRACEEVENT
_DEVICE_RESOURCESENTRY.fields_by_name['value'].message_type = _RESOURCE
_DEVICE_RESOURCESENTRY.containing_type = _DEVICE
_DEVICE.fields_by_name['resources'].message_type = _DEVICE_RESOURCESENTRY
_TRACEEVENT_ARGSENTRY.containing_type = _TRACEEVENT
_TRACEEVENT.fields_by_name['args'].message_type = _TRACEEVENT_ARGSENTRY
DESCRIPTOR.message_types_by_name['Trace'] = _TRACE
DESCRIPTOR.message_types_by_name['Device'] = _DEVICE
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
DESCRIPTOR.message_types_by_name['TraceEvent'] = _TRACEEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
Trace = _reflection.GeneratedProtocolMessageType('Trace', (_message.Message,), {'DevicesEntry': _reflection.GeneratedProtocolMessageType('DevicesEntry', (_message.Message,), {'DESCRIPTOR': _TRACE_DEVICESENTRY, '__module__': 'tensorflow.core.profiler.protobuf.trace_events_pb2'}), 'DESCRIPTOR': _TRACE, '__module__': 'tensorflow.core.profiler.protobuf.trace_events_pb2'})
_sym_db.RegisterMessage(Trace)
_sym_db.RegisterMessage(Trace.DevicesEntry)
Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {'ResourcesEntry': _reflection.GeneratedProtocolMessageType('ResourcesEntry', (_message.Message,), {'DESCRIPTOR': _DEVICE_RESOURCESENTRY, '__module__': 'tensorflow.core.profiler.protobuf.trace_events_pb2'}), 'DESCRIPTOR': _DEVICE, '__module__': 'tensorflow.core.profiler.protobuf.trace_events_pb2'})
_sym_db.RegisterMessage(Device)
_sym_db.RegisterMessage(Device.ResourcesEntry)
Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {'DESCRIPTOR': _RESOURCE, '__module__': 'tensorflow.core.profiler.protobuf.trace_events_pb2'})
_sym_db.RegisterMessage(Resource)
TraceEvent = _reflection.GeneratedProtocolMessageType('TraceEvent', (_message.Message,), {'ArgsEntry': _reflection.GeneratedProtocolMessageType('ArgsEntry', (_message.Message,), {'DESCRIPTOR': _TRACEEVENT_ARGSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.trace_events_pb2'}), 'DESCRIPTOR': _TRACEEVENT, '__module__': 'tensorflow.core.profiler.protobuf.trace_events_pb2'})
_sym_db.RegisterMessage(TraceEvent)
_sym_db.RegisterMessage(TraceEvent.ArgsEntry)
DESCRIPTOR._options = None
_TRACE_DEVICESENTRY._options = None
_DEVICE_RESOURCESENTRY._options = None
_TRACEEVENT_ARGSENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.profiler.protobuf import diagnostics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/pod_stats.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n1tensorflow/core/profiler/protobuf/pod_stats.proto\x12\x13tensorflow.profiler\x1a3tensorflow/core/profiler/protobuf/diagnostics.proto"/\n\x13StepBreakdownEvents\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t"\xd7\x01\n\x10PodStatsDatabase\x12=\n\x10pod_stats_record\x18\x01 \x03(\x0b2#.tensorflow.profiler.PodStatsRecord\x125\n\x0bdiagnostics\x18\x03 \x01(\x0b2 .tensorflow.profiler.Diagnostics\x12G\n\x15step_breakdown_events\x18\x04 \x03(\x0b2(.tensorflow.profiler.StepBreakdownEventsJ\x04\x08\x02\x10\x03"\xdb\x02\n\x0ePodStatsRecord\x12\x11\n\thost_name\x18\x01 \x01(\t\x12\x0f\n\x07chip_id\x18\x02 \x01(\x05\x12\x0f\n\x07node_id\x18\x03 \x01(\x05\x12\x10\n\x08step_num\x18\x04 \x01(\r\x12\x19\n\x11total_duration_us\x18\x05 \x01(\x01\x12S\n\x11step_breakdown_us\x18\x13 \x03(\x0b28.tensorflow.profiler.PodStatsRecord.StepBreakdownUsEntry\x12\x12\n\nbottleneck\x18\x0e \x01(\t\x1a6\n\x14StepBreakdownUsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01:\x028\x01J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rJ\x04\x08\r\x10\x0eJ\x04\x08\x0f\x10\x10J\x04\x08\x10\x10\x11J\x04\x08\x11\x10\x12J\x04\x08\x12\x10\x13b\x06proto3', dependencies=[tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2.DESCRIPTOR])
_STEPBREAKDOWNEVENTS = _descriptor.Descriptor(name='StepBreakdownEvents', full_name='tensorflow.profiler.StepBreakdownEvents', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.StepBreakdownEvents.id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.StepBreakdownEvents.name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=127, serialized_end=174)
_PODSTATSDATABASE = _descriptor.Descriptor(name='PodStatsDatabase', full_name='tensorflow.profiler.PodStatsDatabase', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='pod_stats_record', full_name='tensorflow.profiler.PodStatsDatabase.pod_stats_record', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='diagnostics', full_name='tensorflow.profiler.PodStatsDatabase.diagnostics', index=1, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_breakdown_events', full_name='tensorflow.profiler.PodStatsDatabase.step_breakdown_events', index=2, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=177, serialized_end=392)
_PODSTATSRECORD_STEPBREAKDOWNUSENTRY = _descriptor.Descriptor(name='StepBreakdownUsEntry', full_name='tensorflow.profiler.PodStatsRecord.StepBreakdownUsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PodStatsRecord.StepBreakdownUsEntry.key', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PodStatsRecord.StepBreakdownUsEntry.value', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=616, serialized_end=670)
_PODSTATSRECORD = _descriptor.Descriptor(name='PodStatsRecord', full_name='tensorflow.profiler.PodStatsRecord', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host_name', full_name='tensorflow.profiler.PodStatsRecord.host_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='chip_id', full_name='tensorflow.profiler.PodStatsRecord.chip_id', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_id', full_name='tensorflow.profiler.PodStatsRecord.node_id', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_num', full_name='tensorflow.profiler.PodStatsRecord.step_num', index=3, number=4, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_duration_us', full_name='tensorflow.profiler.PodStatsRecord.total_duration_us', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_breakdown_us', full_name='tensorflow.profiler.PodStatsRecord.step_breakdown_us', index=5, number=19, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bottleneck', full_name='tensorflow.profiler.PodStatsRecord.bottleneck', index=6, number=14, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_PODSTATSRECORD_STEPBREAKDOWNUSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=395, serialized_end=742)
_PODSTATSDATABASE.fields_by_name['pod_stats_record'].message_type = _PODSTATSRECORD
_PODSTATSDATABASE.fields_by_name['diagnostics'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2._DIAGNOSTICS
_PODSTATSDATABASE.fields_by_name['step_breakdown_events'].message_type = _STEPBREAKDOWNEVENTS
_PODSTATSRECORD_STEPBREAKDOWNUSENTRY.containing_type = _PODSTATSRECORD
_PODSTATSRECORD.fields_by_name['step_breakdown_us'].message_type = _PODSTATSRECORD_STEPBREAKDOWNUSENTRY
DESCRIPTOR.message_types_by_name['StepBreakdownEvents'] = _STEPBREAKDOWNEVENTS
DESCRIPTOR.message_types_by_name['PodStatsDatabase'] = _PODSTATSDATABASE
DESCRIPTOR.message_types_by_name['PodStatsRecord'] = _PODSTATSRECORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
StepBreakdownEvents = _reflection.GeneratedProtocolMessageType('StepBreakdownEvents', (_message.Message,), {'DESCRIPTOR': _STEPBREAKDOWNEVENTS, '__module__': 'tensorflow.core.profiler.protobuf.pod_stats_pb2'})
_sym_db.RegisterMessage(StepBreakdownEvents)
PodStatsDatabase = _reflection.GeneratedProtocolMessageType('PodStatsDatabase', (_message.Message,), {'DESCRIPTOR': _PODSTATSDATABASE, '__module__': 'tensorflow.core.profiler.protobuf.pod_stats_pb2'})
_sym_db.RegisterMessage(PodStatsDatabase)
PodStatsRecord = _reflection.GeneratedProtocolMessageType('PodStatsRecord', (_message.Message,), {'StepBreakdownUsEntry': _reflection.GeneratedProtocolMessageType('StepBreakdownUsEntry', (_message.Message,), {'DESCRIPTOR': _PODSTATSRECORD_STEPBREAKDOWNUSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.pod_stats_pb2'}), 'DESCRIPTOR': _PODSTATSRECORD, '__module__': 'tensorflow.core.profiler.protobuf.pod_stats_pb2'})
_sym_db.RegisterMessage(PodStatsRecord)
_sym_db.RegisterMessage(PodStatsRecord.StepBreakdownUsEntry)
_PODSTATSRECORD_STEPBREAKDOWNUSENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/python/keras/protobuf/projector_config.proto', package='third_party.tensorflow.python.keras.protobuf', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n7tensorflow/python/keras/protobuf/projector_config.proto\x12,third_party.tensorflow.python.keras.protobuf">\n\x0eSpriteMetadata\x12\x12\n\nimage_path\x18\x01 \x01(\t\x12\x18\n\x10single_image_dim\x18\x02 \x03(\r"\xcc\x01\n\rEmbeddingInfo\x12\x13\n\x0btensor_name\x18\x01 \x01(\t\x12\x15\n\rmetadata_path\x18\x02 \x01(\t\x12\x16\n\x0ebookmarks_path\x18\x03 \x01(\t\x12\x14\n\x0ctensor_shape\x18\x04 \x03(\r\x12L\n\x06sprite\x18\x05 \x01(\x0b2<.third_party.tensorflow.python.keras.protobuf.SpriteMetadata\x12\x13\n\x0btensor_path\x18\x06 \x01(\t"\x9f\x01\n\x0fProjectorConfig\x12\x1d\n\x15model_checkpoint_path\x18\x01 \x01(\t\x12O\n\nembeddings\x18\x02 \x03(\x0b2;.third_party.tensorflow.python.keras.protobuf.EmbeddingInfo\x12\x1c\n\x14model_checkpoint_dir\x18\x03 \x01(\tb\x06proto3')
_SPRITEMETADATA = _descriptor.Descriptor(name='SpriteMetadata', full_name='third_party.tensorflow.python.keras.protobuf.SpriteMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='image_path', full_name='third_party.tensorflow.python.keras.protobuf.SpriteMetadata.image_path', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='single_image_dim', full_name='third_party.tensorflow.python.keras.protobuf.SpriteMetadata.single_image_dim', index=1, number=2, type=13, cpp_type=3, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=105, serialized_end=167)
_EMBEDDINGINFO = _descriptor.Descriptor(name='EmbeddingInfo', full_name='third_party.tensorflow.python.keras.protobuf.EmbeddingInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tensor_name', full_name='third_party.tensorflow.python.keras.protobuf.EmbeddingInfo.tensor_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata_path', full_name='third_party.tensorflow.python.keras.protobuf.EmbeddingInfo.metadata_path', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bookmarks_path', full_name='third_party.tensorflow.python.keras.protobuf.EmbeddingInfo.bookmarks_path', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_shape', full_name='third_party.tensorflow.python.keras.protobuf.EmbeddingInfo.tensor_shape', index=3, number=4, type=13, cpp_type=3, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='sprite', full_name='third_party.tensorflow.python.keras.protobuf.EmbeddingInfo.sprite', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_path', full_name='third_party.tensorflow.python.keras.protobuf.EmbeddingInfo.tensor_path', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=170, serialized_end=374)
_PROJECTORCONFIG = _descriptor.Descriptor(name='ProjectorConfig', full_name='third_party.tensorflow.python.keras.protobuf.ProjectorConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='model_checkpoint_path', full_name='third_party.tensorflow.python.keras.protobuf.ProjectorConfig.model_checkpoint_path', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='embeddings', full_name='third_party.tensorflow.python.keras.protobuf.ProjectorConfig.embeddings', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='model_checkpoint_dir', full_name='third_party.tensorflow.python.keras.protobuf.ProjectorConfig.model_checkpoint_dir', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=377, serialized_end=536)
_EMBEDDINGINFO.fields_by_name['sprite'].message_type = _SPRITEMETADATA
_PROJECTORCONFIG.fields_by_name['embeddings'].message_type = _EMBEDDINGINFO
DESCRIPTOR.message_types_by_name['SpriteMetadata'] = _SPRITEMETADATA
DESCRIPTOR.message_types_by_name['EmbeddingInfo'] = _EMBEDDINGINFO
DESCRIPTOR.message_types_by_name['ProjectorConfig'] = _PROJECTORCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
SpriteMetadata = _reflection.GeneratedProtocolMessageType('SpriteMetadata', (_message.Message,), {'DESCRIPTOR': _SPRITEMETADATA, '__module__': 'tensorflow.python.keras.protobuf.projector_config_pb2'})
_sym_db.RegisterMessage(SpriteMetadata)
EmbeddingInfo = _reflection.GeneratedProtocolMessageType('EmbeddingInfo', (_message.Message,), {'DESCRIPTOR': _EMBEDDINGINFO, '__module__': 'tensorflow.python.keras.protobuf.projector_config_pb2'})
_sym_db.RegisterMessage(EmbeddingInfo)
ProjectorConfig = _reflection.GeneratedProtocolMessageType('ProjectorConfig', (_message.Message,), {'DESCRIPTOR': _PROJECTORCONFIG, '__module__': 'tensorflow.python.keras.protobuf.projector_config_pb2'})
_sym_db.RegisterMessage(ProjectorConfig)




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/tpu/kernels/tpu_compilation_cache_common.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n>tensorflow/core/tpu/kernels/tpu_compilation_cache_common.proto\x12\x0etensorflow.tpu"=\n\x19TpuCompilationUidAndIndex\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x13\n\x0bproto_index\x18\x02 \x01(\x05"\xb9\x01\n\x14GetTpuProgramRequest\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12B\n\ruid_and_index\x18\x02 \x01(\x0b2).tensorflow.tpu.TpuCompilationUidAndIndexH\x00\x12A\n\x0cfetch_target\x18\x03 \x01(\x0e2+.tensorflow.tpu.CompilationCacheFetchTargetB\x0b\n\tkey_oneof*R\n\x1bCompilationCacheFetchTarget\x12\x0b\n\x07INVALID\x10\x00\x12\x08\n\x04MAIN\x10\x01\x12\x0c\n\x08SHARDING\x10\x02\x12\x0e\n\nUNSHARDING\x10\x03b\x06proto3')
_COMPILATIONCACHEFETCHTARGET = _descriptor.EnumDescriptor(name='CompilationCacheFetchTarget', full_name='tensorflow.tpu.CompilationCacheFetchTarget', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='MAIN', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='SHARDING', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='UNSHARDING', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=333, serialized_end=415)
_sym_db.RegisterEnumDescriptor(_COMPILATIONCACHEFETCHTARGET)
CompilationCacheFetchTarget = enum_type_wrapper.EnumTypeWrapper(_COMPILATIONCACHEFETCHTARGET)
INVALID = 0
MAIN = 1
SHARDING = 2
UNSHARDING = 3
_TPUCOMPILATIONUIDANDINDEX = _descriptor.Descriptor(name='TpuCompilationUidAndIndex', full_name='tensorflow.tpu.TpuCompilationUidAndIndex', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='uid', full_name='tensorflow.tpu.TpuCompilationUidAndIndex.uid', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='proto_index', full_name='tensorflow.tpu.TpuCompilationUidAndIndex.proto_index', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=82, serialized_end=143)
_GETTPUPROGRAMREQUEST = _descriptor.Descriptor(name='GetTpuProgramRequest', full_name='tensorflow.tpu.GetTpuProgramRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.tpu.GetTpuProgramRequest.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='uid_and_index', full_name='tensorflow.tpu.GetTpuProgramRequest.uid_and_index', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fetch_target', full_name='tensorflow.tpu.GetTpuProgramRequest.fetch_target', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='key_oneof', full_name='tensorflow.tpu.GetTpuProgramRequest.key_oneof', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=146, serialized_end=331)
_GETTPUPROGRAMREQUEST.fields_by_name['uid_and_index'].message_type = _TPUCOMPILATIONUIDANDINDEX
_GETTPUPROGRAMREQUEST.fields_by_name['fetch_target'].enum_type = _COMPILATIONCACHEFETCHTARGET
_GETTPUPROGRAMREQUEST.oneofs_by_name['key_oneof'].fields.append(_GETTPUPROGRAMREQUEST.fields_by_name['key'])
_GETTPUPROGRAMREQUEST.fields_by_name['key'].containing_oneof = _GETTPUPROGRAMREQUEST.oneofs_by_name['key_oneof']
_GETTPUPROGRAMREQUEST.oneofs_by_name['key_oneof'].fields.append(_GETTPUPROGRAMREQUEST.fields_by_name['uid_and_index'])
_GETTPUPROGRAMREQUEST.fields_by_name['uid_and_index'].containing_oneof = _GETTPUPROGRAMREQUEST.oneofs_by_name['key_oneof']
DESCRIPTOR.message_types_by_name['TpuCompilationUidAndIndex'] = _TPUCOMPILATIONUIDANDINDEX
DESCRIPTOR.message_types_by_name['GetTpuProgramRequest'] = _GETTPUPROGRAMREQUEST
DESCRIPTOR.enum_types_by_name['CompilationCacheFetchTarget'] = _COMPILATIONCACHEFETCHTARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TpuCompilationUidAndIndex = _reflection.GeneratedProtocolMessageType('TpuCompilationUidAndIndex', (_message.Message,), {'DESCRIPTOR': _TPUCOMPILATIONUIDANDINDEX, '__module__': 'tensorflow.core.tpu.kernels.tpu_compilation_cache_common_pb2'})
_sym_db.RegisterMessage(TpuCompilationUidAndIndex)
GetTpuProgramRequest = _reflection.GeneratedProtocolMessageType('GetTpuProgramRequest', (_message.Message,), {'DESCRIPTOR': _GETTPUPROGRAMREQUEST, '__module__': 'tensorflow.core.tpu.kernels.tpu_compilation_cache_common_pb2'})
_sym_db.RegisterMessage(GetTpuProgramRequest)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/tpu/tpu_embedding_output_layout.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n>tensorflow/core/protobuf/tpu/tpu_embedding_output_layout.proto\x12\x0etensorflow.tpu"\x8b\x05\n\x18TPUEmbeddingOutputLayout\x12G\n\x05table\x18\x01 \x03(\x0b28.tensorflow.tpu.TPUEmbeddingOutputLayout.TableDescriptor\x12N\n\x06output\x18\x02 \x03(\x0b2>.tensorflow.tpu.TPUEmbeddingOutputLayout.EmbeddingOutputTensor\x1aP\n\x0eOutputLocation\x12\x14\n\x0ctensor_index\x18\x01 \x01(\x05\x12\x13\n\x0bdim0_offset\x18\x02 \x01(\x05\x12\x13\n\x0bdim1_offset\x18\x03 \x01(\x05\x1ae\n\x11FeatureDescriptor\x12P\n\x0foutput_location\x18\x01 \x03(\x0b27.tensorflow.tpu.TPUEmbeddingOutputLayout.OutputLocation\x1a^\n\x0fTableDescriptor\x12K\n\x07feature\x18\x01 \x03(\x0b2:.tensorflow.tpu.TPUEmbeddingOutputLayout.FeatureDescriptor\x1aC\n\x10TwoDOutputTensor\x12\x1c\n\x14dim0_size_per_sample\x18\x02 \x01(\x05\x12\x11\n\tdim1_size\x18\x01 \x01(\x05\x1at\n\x15EmbeddingOutputTensor\x12J\n\x05two_d\x18\x04 \x01(\x0b29.tensorflow.tpu.TPUEmbeddingOutputLayout.TwoDOutputTensorH\x00B\x0f\n\routput_format:\x02\x18\x01b\x06proto3')
_TPUEMBEDDINGOUTPUTLAYOUT_OUTPUTLOCATION = _descriptor.Descriptor(name='OutputLocation', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.OutputLocation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tensor_index', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.OutputLocation.tensor_index', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dim0_offset', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.OutputLocation.dim0_offset', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dim1_offset', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.OutputLocation.dim1_offset', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=264, serialized_end=344)
_TPUEMBEDDINGOUTPUTLAYOUT_FEATUREDESCRIPTOR = _descriptor.Descriptor(name='FeatureDescriptor', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.FeatureDescriptor', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='output_location', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.FeatureDescriptor.output_location', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=346, serialized_end=447)
_TPUEMBEDDINGOUTPUTLAYOUT_TABLEDESCRIPTOR = _descriptor.Descriptor(name='TableDescriptor', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.TableDescriptor', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='feature', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.TableDescriptor.feature', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=449, serialized_end=543)
_TPUEMBEDDINGOUTPUTLAYOUT_TWODOUTPUTTENSOR = _descriptor.Descriptor(name='TwoDOutputTensor', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.TwoDOutputTensor', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dim0_size_per_sample', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.TwoDOutputTensor.dim0_size_per_sample', index=0, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dim1_size', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.TwoDOutputTensor.dim1_size', index=1, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=545, serialized_end=612)
_TPUEMBEDDINGOUTPUTLAYOUT_EMBEDDINGOUTPUTTENSOR = _descriptor.Descriptor(name='EmbeddingOutputTensor', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.EmbeddingOutputTensor', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='two_d', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.EmbeddingOutputTensor.two_d', index=0, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='output_format', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.EmbeddingOutputTensor.output_format', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=614, serialized_end=730)
_TPUEMBEDDINGOUTPUTLAYOUT = _descriptor.Descriptor(name='TPUEmbeddingOutputLayout', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='table', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.table', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output', full_name='tensorflow.tpu.TPUEmbeddingOutputLayout.output', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TPUEMBEDDINGOUTPUTLAYOUT_OUTPUTLOCATION, _TPUEMBEDDINGOUTPUTLAYOUT_FEATUREDESCRIPTOR, _TPUEMBEDDINGOUTPUTLAYOUT_TABLEDESCRIPTOR, _TPUEMBEDDINGOUTPUTLAYOUT_TWODOUTPUTTENSOR, _TPUEMBEDDINGOUTPUTLAYOUT_EMBEDDINGOUTPUTTENSOR], enum_types=[], serialized_options=b'\x18\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=83, serialized_end=734)
_TPUEMBEDDINGOUTPUTLAYOUT_OUTPUTLOCATION.containing_type = _TPUEMBEDDINGOUTPUTLAYOUT
_TPUEMBEDDINGOUTPUTLAYOUT_FEATUREDESCRIPTOR.fields_by_name['output_location'].message_type = _TPUEMBEDDINGOUTPUTLAYOUT_OUTPUTLOCATION
_TPUEMBEDDINGOUTPUTLAYOUT_FEATUREDESCRIPTOR.containing_type = _TPUEMBEDDINGOUTPUTLAYOUT
_TPUEMBEDDINGOUTPUTLAYOUT_TABLEDESCRIPTOR.fields_by_name['feature'].message_type = _TPUEMBEDDINGOUTPUTLAYOUT_FEATUREDESCRIPTOR
_TPUEMBEDDINGOUTPUTLAYOUT_TABLEDESCRIPTOR.containing_type = _TPUEMBEDDINGOUTPUTLAYOUT
_TPUEMBEDDINGOUTPUTLAYOUT_TWODOUTPUTTENSOR.containing_type = _TPUEMBEDDINGOUTPUTLAYOUT
_TPUEMBEDDINGOUTPUTLAYOUT_EMBEDDINGOUTPUTTENSOR.fields_by_name['two_d'].message_type = _TPUEMBEDDINGOUTPUTLAYOUT_TWODOUTPUTTENSOR
_TPUEMBEDDINGOUTPUTLAYOUT_EMBEDDINGOUTPUTTENSOR.containing_type = _TPUEMBEDDINGOUTPUTLAYOUT
_TPUEMBEDDINGOUTPUTLAYOUT_EMBEDDINGOUTPUTTENSOR.oneofs_by_name['output_format'].fields.append(_TPUEMBEDDINGOUTPUTLAYOUT_EMBEDDINGOUTPUTTENSOR.fields_by_name['two_d'])
_TPUEMBEDDINGOUTPUTLAYOUT_EMBEDDINGOUTPUTTENSOR.fields_by_name['two_d'].containing_oneof = _TPUEMBEDDINGOUTPUTLAYOUT_EMBEDDINGOUTPUTTENSOR.oneofs_by_name['output_format']
_TPUEMBEDDINGOUTPUTLAYOUT.fields_by_name['table'].message_type = _TPUEMBEDDINGOUTPUTLAYOUT_TABLEDESCRIPTOR
_TPUEMBEDDINGOUTPUTLAYOUT.fields_by_name['output'].message_type = _TPUEMBEDDINGOUTPUTLAYOUT_EMBEDDINGOUTPUTTENSOR
DESCRIPTOR.message_types_by_name['TPUEmbeddingOutputLayout'] = _TPUEMBEDDINGOUTPUTLAYOUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TPUEmbeddingOutputLayout = _reflection.GeneratedProtocolMessageType('TPUEmbeddingOutputLayout', (_message.Message,), {'OutputLocation': _reflection.GeneratedProtocolMessageType('OutputLocation', (_message.Message,), {'DESCRIPTOR': _TPUEMBEDDINGOUTPUTLAYOUT_OUTPUTLOCATION, '__module__': 'tensorflow.core.protobuf.tpu.tpu_embedding_output_layout_pb2'}), 'FeatureDescriptor': _reflection.GeneratedProtocolMessageType('FeatureDescriptor', (_message.Message,), {'DESCRIPTOR': _TPUEMBEDDINGOUTPUTLAYOUT_FEATUREDESCRIPTOR, '__module__': 'tensorflow.core.protobuf.tpu.tpu_embedding_output_layout_pb2'}), 'TableDescriptor': _reflection.GeneratedProtocolMessageType('TableDescriptor', (_message.Message,), {'DESCRIPTOR': _TPUEMBEDDINGOUTPUTLAYOUT_TABLEDESCRIPTOR, '__module__': 'tensorflow.core.protobuf.tpu.tpu_embedding_output_layout_pb2'}), 'TwoDOutputTensor': _reflection.GeneratedProtocolMessageType('TwoDOutputTensor', (_message.Message,), {'DESCRIPTOR': _TPUEMBEDDINGOUTPUTLAYOUT_TWODOUTPUTTENSOR, '__module__': 'tensorflow.core.protobuf.tpu.tpu_embedding_output_layout_pb2'}), 'EmbeddingOutputTensor': _reflection.GeneratedProtocolMessageType('EmbeddingOutputTensor', (_message.Message,), {'DESCRIPTOR': _TPUEMBEDDINGOUTPUTLAYOUT_EMBEDDINGOUTPUTTENSOR, '__module__': 'tensorflow.core.protobuf.tpu.tpu_embedding_output_layout_pb2'}), 'DESCRIPTOR': _TPUEMBEDDINGOUTPUTLAYOUT, '__module__': 'tensorflow.core.protobuf.tpu.tpu_embedding_output_layout_pb2'})
_sym_db.RegisterMessage(TPUEmbeddingOutputLayout)
_sym_db.RegisterMessage(TPUEmbeddingOutputLayout.OutputLocation)
_sym_db.RegisterMessage(TPUEmbeddingOutputLayout.FeatureDescriptor)
_sym_db.RegisterMessage(TPUEmbeddingOutputLayout.TableDescriptor)
_sym_db.RegisterMessage(TPUEmbeddingOutputLayout.TwoDOutputTensor)
_sym_db.RegisterMessage(TPUEmbeddingOutputLayout.EmbeddingOutputTensor)
_TPUEMBEDDINGOUTPUTLAYOUT._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/profiler_options.proto', package='tensorflow', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n/tensorflow/core/profiler/profiler_options.proto\x12\ntensorflow"\xed\x02\n\x0eProfileOptions\x12\x0f\n\x07version\x18\x05 \x01(\r\x12:\n\x0bdevice_type\x18\x06 \x01(\x0e2%.tensorflow.ProfileOptions.DeviceType\x12\x1b\n\x13include_dataset_ops\x18\x01 \x01(\x08\x12\x19\n\x11host_tracer_level\x18\x02 \x01(\r\x12\x1b\n\x13device_tracer_level\x18\x03 \x01(\r\x12\x1b\n\x13python_tracer_level\x18\x04 \x01(\r\x12\x18\n\x10enable_hlo_proto\x18\x07 \x01(\x08\x12\x1a\n\x12start_timestamp_ns\x18\x08 \x01(\x04\x12\x13\n\x0bduration_ms\x18\t \x01(\x04\x12\x17\n\x0frepository_path\x18\n \x01(\t"8\n\nDeviceType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x07\n\x03CPU\x10\x01\x12\x07\n\x03GPU\x10\x02\x12\x07\n\x03TPU\x10\x03"\xd0\x01\n#RemoteProfilerSessionManagerOptions\x124\n\x10profiler_options\x18\x01 \x01(\x0b2\x1a.tensorflow.ProfileOptions\x12\x19\n\x11service_addresses\x18\x02 \x03(\t\x12%\n\x1dsession_creation_timestamp_ns\x18\x03 \x01(\x04\x12\x1f\n\x17max_session_duration_ms\x18\x04 \x01(\x04\x12\x10\n\x08delay_ms\x18\x05 \x01(\x04b\x06proto3')
_PROFILEOPTIONS_DEVICETYPE = _descriptor.EnumDescriptor(name='DeviceType', full_name='tensorflow.ProfileOptions.DeviceType', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNSPECIFIED', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='CPU', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='GPU', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TPU', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=373, serialized_end=429)
_sym_db.RegisterEnumDescriptor(_PROFILEOPTIONS_DEVICETYPE)
_PROFILEOPTIONS = _descriptor.Descriptor(name='ProfileOptions', full_name='tensorflow.ProfileOptions', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='version', full_name='tensorflow.ProfileOptions.version', index=0, number=5, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.ProfileOptions.device_type', index=1, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='include_dataset_ops', full_name='tensorflow.ProfileOptions.include_dataset_ops', index=2, number=1, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_tracer_level', full_name='tensorflow.ProfileOptions.host_tracer_level', index=3, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_tracer_level', full_name='tensorflow.ProfileOptions.device_tracer_level', index=4, number=3, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='python_tracer_level', full_name='tensorflow.ProfileOptions.python_tracer_level', index=5, number=4, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='enable_hlo_proto', full_name='tensorflow.ProfileOptions.enable_hlo_proto', index=6, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_timestamp_ns', full_name='tensorflow.ProfileOptions.start_timestamp_ns', index=7, number=8, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='duration_ms', full_name='tensorflow.ProfileOptions.duration_ms', index=8, number=9, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='repository_path', full_name='tensorflow.ProfileOptions.repository_path', index=9, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_PROFILEOPTIONS_DEVICETYPE], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=64, serialized_end=429)
_REMOTEPROFILERSESSIONMANAGEROPTIONS = _descriptor.Descriptor(name='RemoteProfilerSessionManagerOptions', full_name='tensorflow.RemoteProfilerSessionManagerOptions', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='profiler_options', full_name='tensorflow.RemoteProfilerSessionManagerOptions.profiler_options', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='service_addresses', full_name='tensorflow.RemoteProfilerSessionManagerOptions.service_addresses', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='session_creation_timestamp_ns', full_name='tensorflow.RemoteProfilerSessionManagerOptions.session_creation_timestamp_ns', index=2, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_session_duration_ms', full_name='tensorflow.RemoteProfilerSessionManagerOptions.max_session_duration_ms', index=3, number=4, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='delay_ms', full_name='tensorflow.RemoteProfilerSessionManagerOptions.delay_ms', index=4, number=5, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=432, serialized_end=640)
_PROFILEOPTIONS.fields_by_name['device_type'].enum_type = _PROFILEOPTIONS_DEVICETYPE
_PROFILEOPTIONS_DEVICETYPE.containing_type = _PROFILEOPTIONS
_REMOTEPROFILERSESSIONMANAGEROPTIONS.fields_by_name['profiler_options'].message_type = _PROFILEOPTIONS
DESCRIPTOR.message_types_by_name['ProfileOptions'] = _PROFILEOPTIONS
DESCRIPTOR.message_types_by_name['RemoteProfilerSessionManagerOptions'] = _REMOTEPROFILERSESSIONMANAGEROPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ProfileOptions = _reflection.GeneratedProtocolMessageType('ProfileOptions', (_message.Message,), {'DESCRIPTOR': _PROFILEOPTIONS, '__module__': 'tensorflow.core.profiler.profiler_options_pb2'})
_sym_db.RegisterMessage(ProfileOptions)
RemoteProfilerSessionManagerOptions = _reflection.GeneratedProtocolMessageType('RemoteProfilerSessionManagerOptions', (_message.Message,), {'DESCRIPTOR': _REMOTEPROFILERSESSIONMANAGEROPTIONS, '__module__': 'tensorflow.core.profiler.profiler_options_pb2'})
_sym_db.RegisterMessage(RemoteProfilerSessionManagerOptions)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.framework import attr_value_pb2 as tensorflow_dot_core_dot_framework_dot_attr__value__pb2
from .....tensorflow.core.framework import function_pb2 as tensorflow_dot_core_dot_framework_dot_function__pb2
from .....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from .....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from .....tensorflow.core.protobuf.tpu import compile_metadata_pb2 as tensorflow_dot_core_dot_protobuf_dot_tpu_dot_compile__metadata__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/tpu/kernels/tpu_compile.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/core/tpu/kernels/tpu_compile.proto\x12\x0etensorflow.tpu\x1a*tensorflow/core/framework/attr_value.proto\x1a(tensorflow/core/framework/function.proto\x1a&tensorflow/core/framework/tensor.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a3tensorflow/core/protobuf/tpu/compile_metadata.proto"\xbc\x03\n\x1aTpuCompilationRequestProto\x12\x18\n\x10use_experimental\x18\x01 \x01(\x08\x12\x10\n\x08use_mlir\x18\x02 \x01(\x08\x12\x19\n\x11return_hlo_protos\x18\x03 \x01(\x08\x12%\n\x1dunload_cache_on_session_close\x18\x04 \x01(\x08\x129\n\x08metadata\x18\x05 \x01(\x0b2\'.tensorflow.tpu.TPUCompileMetadataProto\x120\n\narg_shapes\x18\x06 \x03(\x0b2\x1c.tensorflow.TensorShapeProto\x125\n\x14guaranteed_constants\x18\x07 \x03(\x0b2\x17.tensorflow.TensorProto\x12\x13\n\x0bmlir_module\x18\x08 \x01(\t\x120\n\x08fdef_lib\x18\t \x01(\x0b2\x1e.tensorflow.FunctionDefLibrary\x12\x19\n\x11graph_def_version\x18\n \x01(\x05\x12*\n\x08function\x18\x0b \x01(\x0b2\x18.tensorflow.NameAttrListb\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_attr__value__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_function__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_tpu_dot_compile__metadata__pb2.DESCRIPTOR])
_TPUCOMPILATIONREQUESTPROTO = _descriptor.Descriptor(name='TpuCompilationRequestProto', full_name='tensorflow.tpu.TpuCompilationRequestProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='use_experimental', full_name='tensorflow.tpu.TpuCompilationRequestProto.use_experimental', index=0, number=1, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_mlir', full_name='tensorflow.tpu.TpuCompilationRequestProto.use_mlir', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='return_hlo_protos', full_name='tensorflow.tpu.TpuCompilationRequestProto.return_hlo_protos', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unload_cache_on_session_close', full_name='tensorflow.tpu.TpuCompilationRequestProto.unload_cache_on_session_close', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.tpu.TpuCompilationRequestProto.metadata', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='arg_shapes', full_name='tensorflow.tpu.TpuCompilationRequestProto.arg_shapes', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='guaranteed_constants', full_name='tensorflow.tpu.TpuCompilationRequestProto.guaranteed_constants', index=6, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='mlir_module', full_name='tensorflow.tpu.TpuCompilationRequestProto.mlir_module', index=7, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fdef_lib', full_name='tensorflow.tpu.TpuCompilationRequestProto.fdef_lib', index=8, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_def_version', full_name='tensorflow.tpu.TpuCompilationRequestProto.graph_def_version', index=9, number=10, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='function', full_name='tensorflow.tpu.TpuCompilationRequestProto.function', index=10, number=11, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=291, serialized_end=735)
_TPUCOMPILATIONREQUESTPROTO.fields_by_name['metadata'].message_type = tensorflow_dot_core_dot_protobuf_dot_tpu_dot_compile__metadata__pb2._TPUCOMPILEMETADATAPROTO
_TPUCOMPILATIONREQUESTPROTO.fields_by_name['arg_shapes'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_TPUCOMPILATIONREQUESTPROTO.fields_by_name['guaranteed_constants'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_TPUCOMPILATIONREQUESTPROTO.fields_by_name['fdef_lib'].message_type = tensorflow_dot_core_dot_framework_dot_function__pb2._FUNCTIONDEFLIBRARY
_TPUCOMPILATIONREQUESTPROTO.fields_by_name['function'].message_type = tensorflow_dot_core_dot_framework_dot_attr__value__pb2._NAMEATTRLIST
DESCRIPTOR.message_types_by_name['TpuCompilationRequestProto'] = _TPUCOMPILATIONREQUESTPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TpuCompilationRequestProto = _reflection.GeneratedProtocolMessageType('TpuCompilationRequestProto', (_message.Message,), {'DESCRIPTOR': _TPUCOMPILATIONREQUESTPROTO, '__module__': 'tensorflow.core.tpu.kernels.tpu_compile_pb2'})
_sym_db.RegisterMessage(TpuCompilationRequestProto)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/tf2xla/host_compute_metadata.proto', package='tensorflow.tf2xla', syntax='proto3', serialized_options=b'\n\x15org.tensorflow.tf2xlaB\x0cTf2XlaProtosP\x01\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n6tensorflow/compiler/tf2xla/host_compute_metadata.proto\x12\x11tensorflow.tf2xla\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"a\n\x0eTensorMetadata\x12"\n\x04type\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto"X\n\x14HostTransferMetadata\x12\x0b\n\x03key\x18\x01 \x01(\t\x123\n\x08metadata\x18\x02 \x03(\x0b2!.tensorflow.tf2xla.TensorMetadata"\x97\x01\n\x13HostComputeMetadata\x12?\n\x0edevice_to_host\x18\x01 \x03(\x0b2\'.tensorflow.tf2xla.HostTransferMetadata\x12?\n\x0ehost_to_device\x18\x02 \x03(\x0b2\'.tensorflow.tf2xla.HostTransferMetadataB*\n\x15org.tensorflow.tf2xlaB\x0cTf2XlaProtosP\x01\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_TENSORMETADATA = _descriptor.Descriptor(name='TensorMetadata', full_name='tensorflow.tf2xla.TensorMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='type', full_name='tensorflow.tf2xla.TensorMetadata.type', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.tf2xla.TensorMetadata.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=162, serialized_end=259)
_HOSTTRANSFERMETADATA = _descriptor.Descriptor(name='HostTransferMetadata', full_name='tensorflow.tf2xla.HostTransferMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.tf2xla.HostTransferMetadata.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.tf2xla.HostTransferMetadata.metadata', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=261, serialized_end=349)
_HOSTCOMPUTEMETADATA = _descriptor.Descriptor(name='HostComputeMetadata', full_name='tensorflow.tf2xla.HostComputeMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device_to_host', full_name='tensorflow.tf2xla.HostComputeMetadata.device_to_host', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_to_device', full_name='tensorflow.tf2xla.HostComputeMetadata.host_to_device', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=352, serialized_end=503)
_TENSORMETADATA.fields_by_name['type'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_TENSORMETADATA.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_HOSTTRANSFERMETADATA.fields_by_name['metadata'].message_type = _TENSORMETADATA
_HOSTCOMPUTEMETADATA.fields_by_name['device_to_host'].message_type = _HOSTTRANSFERMETADATA
_HOSTCOMPUTEMETADATA.fields_by_name['host_to_device'].message_type = _HOSTTRANSFERMETADATA
DESCRIPTOR.message_types_by_name['TensorMetadata'] = _TENSORMETADATA
DESCRIPTOR.message_types_by_name['HostTransferMetadata'] = _HOSTTRANSFERMETADATA
DESCRIPTOR.message_types_by_name['HostComputeMetadata'] = _HOSTCOMPUTEMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TensorMetadata = _reflection.GeneratedProtocolMessageType('TensorMetadata', (_message.Message,), {'DESCRIPTOR': _TENSORMETADATA, '__module__': 'tensorflow.compiler.tf2xla.host_compute_metadata_pb2'})
_sym_db.RegisterMessage(TensorMetadata)
HostTransferMetadata = _reflection.GeneratedProtocolMessageType('HostTransferMetadata', (_message.Message,), {'DESCRIPTOR': _HOSTTRANSFERMETADATA, '__module__': 'tensorflow.compiler.tf2xla.host_compute_metadata_pb2'})
_sym_db.RegisterMessage(HostTransferMetadata)
HostComputeMetadata = _reflection.GeneratedProtocolMessageType('HostComputeMetadata', (_message.Message,), {'DESCRIPTOR': _HOSTCOMPUTEMETADATA, '__module__': 'tensorflow.compiler.tf2xla.host_compute_metadata_pb2'})
_sym_db.RegisterMessage(HostComputeMetadata)
DESCRIPTOR._options = None
